pub enum Marker {
DenoBindgen,
NonBlocking,
}Expand description
markers here denote live attributes that get converted to inert attributes
(as doc attributes) the live version is used by the proc macro library,
while the inert versions (the doc attributes ones) are used by the cli to
control code generation. it does this by using the parser implementation
here to read the marker info
Variants